/** \file vp_debug.h
 * vp_debug.h
 *
 * This file contains the configuration and compile time settings for
 * the VoicePath API debug statements.
 *
 * Copyright (c) 2008, Zarlink Semiconductor, Inc.
 */

#ifndef VP_DEBUG_H
#define VP_DEBUG_H

#include "vp_api_cfg.h"

#ifdef VP_DEBUG

#include <stdio.h>  /* printf() */
#include <stdlib.h> /* exit() */

/* VP-API Debug flags: */
#define VP_DBG_ERROR       0x00000001 /* Any error condition */
#define VP_DBG_WARNING     0x00000002 /* Any warning condition */
#define VP_DBG_INFO        0x00000004 /* Un-categorized information */
#define VP_DBG_API_FUNC    0x00000008 /* API I/F function enter and exit (except tick) */
#define VP_DBG_HAL_FUNC    0x00000010 /* HAL I/F function enter and exit */
#define VP_DBG_SYS_FUNC    0x00000020 /* SysService I/F function enter and exit */

/*
 * These are not documented in the API-II and should be used for internal
 * purposes only. Reserved range (0x00010000 to 0x80000000)
 */
#define DBG_TEST_FUNC   0x01000000 /* Test I/F function enter and exit */
#define DBG_TEST        0x02000000 /* Verbose test debug */
#define DBG_FXO_FUNC    0x04000000 /* FXO Detection Code */
#define DBG_HOOK        0x08000000 /* Hook Based Code */
#define DBG_SEQUENCER   0x10000000 /* Sequencer Based Code */
#define DBG_LINE_STATE  0x20000000 /* Set Line State Based Code */
#define DBG_CALIBRATION 0x40000000 /* VpCalCodec(), VpCalLine(), VpCal() */
#define DBG_CID         0x80000000 /* Caller ID funcitons */

#define DBGSC_DEFAULT VP_DBG_INFO

  #define VP_DOUT(flag, printf_args)            \
    if ((flag) & (dbgFlag))                     \
    {                                           \
        printf(" [%s]", #flag);                 \
        printf ## printf_args;                  \
        printf("\n");                           \
    }

#define VP_ASSERT(condition)       \
    if (!condition) {                            \
        VP_DOUT(VP_DBG_ERROR, ("Assertion failed in %s at line %u: %s", __FILE__, __LINE__, #condition)); \
        exit(-1);                               \
    }

#else
 #define VP_DOUT(flag, printf_args)
 #define VP_ASSERT(condition)
#endif

EXTERN uint32 dbgFlag; /* Decleration for the default flag variable */

#endif



