/*
 * vcp2_hbi.h
 *
 * This file declares HBI-accessible VCP2 registers.
 */

#ifndef _VCP2_HBI_H
#define _VCP2_HBI_H

#include "hbi_common.h"


/* ===========================
    HBI Direct Page Registers
   =========================== */

/* Interrupt indication register */
#define VCP2_HBI_INTIND_PAG          VP_DP
#define VCP2_HBI_INTIND_OFF          0
#define VCP2_HBI_INTIND_LEN          1

/* Interrupt parameter register */
#define VCP2_HBI_INTPARAM_PAG        VP_DP
#define VCP2_HBI_INTPARAM_OFF        1
#define VCP2_HBI_INTPARAM_LEN        1

/* Page offset register */
#define VCP2_HBI_POFFSET_PAG         VP_DP
#define VCP2_HBI_POFFSET_OFF         2
#define VCP2_HBI_POFFSET_LEN         1

/* Software flags register */
#define VCP2_HBI_SW_FLAGS_PAG        VP_DP
#define VCP2_HBI_SW_FLAGS_OFF        3
#define VCP2_HBI_SW_FLAGS_LEN        1

/* Page 255 checksum register */
#define VCP2_HBI_P255_CHECK_PAG      VP_DP
#define VCP2_HBI_P255_CHECK_OFF      4
#define VCP2_HBI_P255_CHECK_LEN      2

/* Page 255 base register */
#define VCP2_HBI_P255_BASE_PAG       VP_DP
#define VCP2_HBI_P255_BASE_OFF       6
#define VCP2_HBI_P255_BASE_LEN       2
#define VCP2_HBI_P255_BASE_HI_PAG    VCP2_HBI_P255_BASE_PAG
#define VCP2_HBI_P255_BASE_HI_OFF    VCP2_HBI_P255_BASE_OFF
#define VCP2_HBI_P255_BASE_HI_LEN    1

/* PCLKSEL register */
#define VCP2_HBI_PCLKSEL_PAG         VP_DP
#define VCP2_HBI_PCLKSEL_OFF         8
#define VCP2_HBI_PCLKSEL_LEN         2

/* CLKGEN_STATUS register */
#define VCP2_HBI_CLKGEN_STATUS_PAG       VP_DP
#define VCP2_HBI_CLKGEN_STATUS_OFF       0xA
#define VCP2_HBI_CLKGEN_STATUS_LEN       2
#define VCP2_HBI_CLKGEN_STATUS_HI_PAG    VCP2_HBI_CLKGEN_STATUS_PAG
#define VCP2_HBI_CLKGEN_STATUS_HI_OFF    VCP2_HBI_CLKGEN_STATUS_OFF
#define VCP2_HBI_CLKGEN_STATUS_HI_LEN    1

/* System interrupt status register */
#define VCP2_HBI_SYSINTSTAT_PAG      VP_DP
#define VCP2_HBI_SYSINTSTAT_OFF      0xC
#define VCP2_HBI_SYSINTSTAT_LEN      1

/* System interrupt mask register */
#define VCP2_HBI_SYSINTMASK_PAG      VP_DP
#define VCP2_HBI_SYSINTMASK_OFF      0xD
#define VCP2_HBI_SYSINTMASK_LEN      1

/* RAM software revision code register */
#define VCP2_HBI_RAMCODE_REV_PAG     VP_DP
#define VCP2_HBI_RAMCODE_REV_OFF     0xE
#define VCP2_HBI_RAMCODE_REV_LEN     1

/* RAM software product ID code (low byte) */
#define VCP2_HBI_PRODUCT_ID_PAG     VP_DP
#define VCP2_HBI_PRODUCT_ID_OFF     0xF
#define VCP2_HBI_PRODUCT_ID_LEN     1

/* Test buffer cursor registers */
#define VCP2_HBI_TESTCURSOR_PAG(n)   VP_DP
#define VCP2_HBI_TESTCURSOR_OFF(n)   (0x74 + (n))
#define VCP2_HBI_TESTCURSOR_LEN      1

/* Boot sense options register */
#define VCP2_HBI_BOOT_SENSE_PAG      VP_DP
#define VCP2_HBI_BOOT_SENSE_OFF      0x14
#define VCP2_HBI_BOOT_SENSE_LEN      2

/* Reset type register */
#define VCP2_HBI_RESET_TYPE_PAG      VP_DP
#define VCP2_HBI_RESET_TYPE_OFF      0x16
#define VCP2_HBI_RESET_TYPE_LEN      1

/* Program entry address register */
#define VCP2_HBI_ENTRY_ADDR_PAG      VP_DP
#define VCP2_HBI_ENTRY_ADDR_OFF      0x18
#define VCP2_HBI_ENTRY_ADDR_LEN      2

/* Timestamp (PCM frame counter) register */
#define VCP2_HBI_TIMESTAMP_PAG       VP_DP
#define VCP2_HBI_TIMESTAMP_OFF       0x1A
#define VCP2_HBI_TIMESTAMP_LEN       1

/* Status bits registers for VpGetLineStatus():
 * n register             n register               n register
 * - -------------------- - ---------------------- - --------------------
 * 0 hook status          1 raw hook status        2 ground key status
 * 3 thermal fault status 4 clock fault status     5 AC fault status
 * 6 DC fault status      7 positive battery fault 8 high battery fault
 * 9 low battery fault
 */
#define VCP2_HBI_LINE_STATUS_PAG(n)  VP_DP
#define VCP2_HBI_LINE_STATUS_OFF(n)  (0x1B + (8 * (n)))
#define VCP2_HBI_LINE_STATUS_LEN     4

/* Number of free DTMF detection resources. */
#define VCP2_HBI_DTMF_FREE_PAG       VP_DP
#define VCP2_HBI_DTMF_FREE_OFF       0x6B
#define VCP2_HBI_DTMF_FREE_LEN       1

/* 4 word bitfield containing a bit for each channel, indicating whether DTMF
 * is enabled (word at the lowest address specifies the status for lines 15
 * through 0 */
#define VCP2_HBI_DTMF_STATUS_PAG     VP_DP
#define VCP2_HBI_DTMF_STATUS_OFF     0x6C
#define VCP2_HBI_DTMF_STATUS_LEN     4

/* One-byte channel number for each test resource; high byte = even resource
 * number */
#define VCP2_HBI_TESTCHAN_PAG(n)     VP_DP
#define VCP2_HBI_TESTCHAN_OFF(n)     (0x10 + (n) / 2)
#define VCP2_HBI_TESTCHAN_LEN        1


/* =========================
    HBI Page 0-15 Registers
   ========================= */

/* Command mailbox */
#define VCP2_HBI_CMD_MBOX_PAG        3
#define VCP2_HBI_CMD_MBOX_OFF(word)  (word)
#define VCP2_HBI_CMD_MBOX_SIZE       128

/* Response mailbox */
#define VCP2_HBI_RESP_MBOX_PAG       4
#define VCP2_HBI_RESP_MBOX_OFF(word) (word)
#define VCP2_HBI_RESP_MBOX_SIZE      100

/* One-byte line termination type for each channel; high byte = even line
 * number */
#define VCP2_HBI_TERMTYPE_PAG(n)     0xF
#define VCP2_HBI_TERMTYPE_OFF(n)     ((n) / 2)
#define VCP2_HBI_TERMTYPE_LEN        1

/* One-byte line state indicator for each line; high byte = even line number */
#define VCP2_HBI_LINESTATE_PAG(n)    0xF
#define VCP2_HBI_LINESTATE_OFF(n)    (0x40 + (n) / 2)
#define VCP2_HBI_LINESTATE_LEN       1


/* ======================
    HBI Page 255 Buffers
   ====================== */

/* AMBA address locations for buffers for verifying line testing algorithms */
#define VCP2_HBI_TESTBUF_LEN         4224
#define VCP2_HBI_TESTBUF_AMBA(n)     ((uint32)0x82000 + n * VCP2_HBI_TESTBUF_LEN * 2)
#define VCP2_HBI_NUM_TEST_BUFS       4


/* ===========
    Constants
   =========== */

/* Bit fields in the high word of CLKGEN_STATUS */
#define VCP2_HBI_CLKGEN_STATUS_HI_CFAIL_GLOBAL 0x0400
#define VCP2_HBI_CLKGEN_STATUS_HI_CFAIL_PCLKB  0x0200
#define VCP2_HBI_CLKGEN_STATUS_HI_CFAIL_PCLKA  0x0100
#define VCP2_HBI_CLKGEN_STATUS_HI_RESET_MASK   0x000F

/* Reset modes */
#define VCP2_HBI_CLKGEN_STATUS_HI_FLASH_BOOT   0x0001
#define VCP2_HBI_CLKGEN_STATUS_HI_HBI_BOOT     0x0003
#define VCP2_HBI_CLKGEN_STATUS_HI_SOFT_RESET   0x0005

/* PCLKSEL bit fields */
#define VCP2_HBI_PCLKSEL_FS_GEN_MASK           0x2000

/* Mailbox flags */
#define VCP2_HBI_SWFLAG_CMD_MBOX               0x0001
#define VCP2_HBI_SWFLAG_RESP_MBOX              0x0002

/* Mailbox command IDs */
typedef enum {
    VCP2_HBI_CMD_NONE           = 0x00,  /* These values are explicitly     */
    VCP2_HBI_CMD_INITDEVICE     = 0x01,  /* stated for quick reference      */
    VCP2_HBI_CMD_CONFIGLINE     = 0x02,  /* during debugging.               */
    VCP2_HBI_CMD_CALCODEC       = 0x03,
    VCP2_HBI_CMD_CALLINE        = 0x04,
    VCP2_HBI_CMD_INITRING       = 0x05,
    VCP2_HBI_CMD_INITMETER      = 0x06,
    VCP2_HBI_CMD_FLUSHEVENTS    = 0x07,
    VCP2_HBI_CMD_GETLOOPCOND    = 0x08,
    VCP2_HBI_CMD_SETLINESTATE   = 0x09,
    VCP2_HBI_CMD_SETLINETONE    = 0x0A,
    VCP2_HBI_CMD_SETRELAYSTATE  = 0x0B,
    VCP2_HBI_CMD_SETRELGAIN     = 0x0C,
    VCP2_HBI_CMD_SENDCID        = 0x0D,
    VCP2_HBI_CMD_STARTMETER     = 0x0E,
    VCP2_HBI_CMD_SETOPTION      = 0x0F,
    VCP2_HBI_CMD_GETOPTION      = 0x10,
    VCP2_HBI_CMD_SELFTEST       = 0x11,
    VCP2_HBI_CMD_TESTLINE       = 0x12,
    VCP2_HBI_CMD_CODECHECKSUM   = 0x13,
    VCP2_HBI_CMD_LOWLEVELCMD    = 0x14,
    VCP2_HBI_CMD_INITCID        = 0x15,
    VCP2_HBI_CMD_CONTINUECID    = 0x16,
    VCP2_HBI_CMD_INITLINE       = 0x17,
    VCP2_HBI_CMD_SENDSIGNAL     = 0x18,
    VCP2_HBI_CMD_DEVICEIOACCESS = 0x19,
    VCP2_HBI_CMD_LOWLEVELCMD16  = 0x1A,
    VCP2_HBI_CMD_SETBATTERIES   = 0x1B,
    VCP2_HBI_CMD_LINEIOACCESS   = 0x20,
    VCP2_HBI_CMD_SLACBOOTLOAD   = 0x22,
    VCP2_HBI_NUM_CMDS,
    VCP2_HBI_CMD_ENUM_SIZE      = FORCE_STANDARD_C_ENUM_SIZE
} MboxCmdIdType;

/* Formats for profile arguments in the command mailbox */
#define VCP2_HBI_PROFILE_OMITTED                ((uint16)0x8000)
#define VCP2_HBI_PROFILE_FOLLOWS                ((uint16)0x8001)
#define VCP2_HBI_PROFILE_IN_TABLE               ((uint16)0x8002)
#define VCP2_HBI_PROFILE_LOCATION(page,offset)  (((uint16)page << 8) | offset)

/* Mailbox field indexes */
#define VCP2_HBI_MBOX_LENGTH    0
#define VCP2_HBI_MBOX_ID_CHAN   1
#define VCP2_HBI_MBOX_PAYLOAD   2

/* Bitmasks for parsing the INTIND register */
#define VCP2_HBI_INTIND_SYSTEM_MASK     0x8000
#define VCP2_HBI_INTIND_EVCAT_MASK      0x7000
#define VCP2_HBI_INTIND_EVCAT_POS       12
#define VCP2_HBI_INTIND_EVID_MASK       0x0F00
#define VCP2_HBI_INTIND_EVID_POS        8
#define VCP2_HBI_INTIND_CHANNEL_MASK    0x00FF
#define VCP2_HBI_INTIND_CHANNEL_POS     0
#define VCP2_HBI_INTIND_DTMF_DIG_MASK   0x001F
#define VCP2_HBI_INTIND_DTMF_TIME_MASK  (~VCP2_HBI_INTIND_DTMF_DIG_MASK)

/* Enumeration for parsing the EVCAT and EVID fields of the INTIND register */
typedef enum
{
    /* Special events */
    VCP2_HBI_EVID_NO_EVENT       = 0x0000,
    VCP2_HBI_EVID_DEBUG          = 0x0100,
    /* Fault Events */
    VCP2_HBI_EVID_BAT_FLT        = 0x1000,
    VCP2_HBI_EVID_CLK_FLT        = 0x1100,
    VCP2_HBI_EVID_THERM_FLT      = 0x1200,
    VCP2_HBI_EVID_DC_FLT         = 0x1300,
    VCP2_HBI_EVID_AC_FLT         = 0x1400,
    VCP2_HBI_EVID_SYNC_FLT       = 0x1500,
    /* Signaling Events */
    VCP2_HBI_EVID_HOOK_OFF       = 0x2000,
    VCP2_HBI_EVID_HOOK_ON        = 0x2100,
    VCP2_HBI_EVID_GKEY_DET       = 0x2200,
    VCP2_HBI_EVID_GKEY_REL       = 0x2300,
    VCP2_HBI_EVID_FLASH          = 0x2400,
    VCP2_HBI_EVID_STARTPULSE     = 0x2500,
    VCP2_HBI_EVID_DTMF_DIG       = 0x2600,
    VCP2_HBI_EVID_PULSE_DIG      = 0x2700,
    VCP2_HBI_EVID_MTONE          = 0x2800,
    VCP2_HBI_EVID_TS_ROLLOVER    = 0x2900,
    VCP2_HBI_EVID_US_TONE_DETECT = 0x2A00,
    VCP2_HBI_EVID_DS_TONE_DETECT = 0x2B00,
    /* Response Events */
    VCP2_HBI_EVID_BOOT_CMP       = 0x3000,
    VCP2_HBI_EVID_LLCMD_TX_CMP   = 0x3100,
    VCP2_HBI_EVID_LLCMD_RX_CMP   = 0x3200,
    VCP2_HBI_EVID_CMD_MBOX       = 0x3300,
    VCP2_HBI_EVID_RD_OPTION      = 0x3400,
    VCP2_HBI_EVID_RD_LOOP        = 0x3500,
    VCP2_HBI_EVID_CAL_CMP        = 0x3600,
    VCP2_HBI_EVID_CAL_BUSY       = 0x3700,
    VCP2_HBI_EVID_GAIN_CMP       = 0x3800,
    VCP2_HBI_EVID_DEV_INIT_CMP   = 0x3A00,
    VCP2_HBI_EVID_LINE_INIT_CMP  = 0x3B00,
    VCP2_HBI_EVID_DEV_IO_AXS_CMP = 0x3C00,
    VCP2_HBI_EVID_LINE_IO_RD_CMP = 0x3D00,
    VCP2_HBI_EVID_LINE_IO_WR_CMP = 0x3E00,
    /* Test Events */
    VCP2_HBI_EVID_TEST_CMP       = 0x4000,
    VCP2_HBI_EVID_DTONE_DET      = 0x4200,
    VCP2_HBI_EVID_DTONE_LOSS     = 0x4300,
    VCP2_HBI_EVID_STEST_CMP      = 0x4400,
    VCP2_HBI_EVID_CHKSUM         = 0x4500,
    /* Call Processing Events */
    VCP2_HBI_EVID_MTR_CMP        = 0x5000,
    VCP2_HBI_EVID_MTR_ABORT      = 0x5100,
    VCP2_HBI_EVID_CID_DATA       = 0x5200,
    VCP2_HBI_EVID_RING_CAD       = 0x5300,
    VCP2_HBI_EVID_SIGNAL_CMP     = 0x5400,
    VCP2_HBI_EVID_MTR_CAD        = 0x5500,
    VCP2_HBI_EVID_TONE_CAD       = 0x5600
} EventIdType;

/* Bitmasks indicating which pins (in each channel's I/O register) can be used
   as GPIOs, based on the line termination type: */
#define VCP2_GPIOMASK_FXS_GENERIC   0x0B
#define VCP2_GPIOMASK_FXS_ISOLATE   0x0F    /* not implemented yet */
#define VCP2_GPIOMASK_FXS_TITO_TL_R 0x08
#define VCP2_GPIOMASK_FXS_CO_TL     0x09
#define VCP2_GPIOMASK_FXS_75181     0x0E
#define VCP2_GPIOMASK_FXS_75282     0x00
#define VCP2_GPIOMASK_FXS_RDT       0x09
#define VCP2_GPIOMASK_FXS_RR        0x09
#define VCP2_GPIOMASK_SPLITTER      0x0F    /* not implemented yet */
#define VCP2_GPIOMASK_FXS_TO_TL     0x09

/* Boot-up default option values (these should be defined to whatever
   the option values are set to by VpInitDevice() and VpInitLine()): */

/* VP_DEVICE_OPTION_ID_PULSE */
#define VCP2_DFLT_PULSE_BREAK_MIN           (33 * 8)    /* == 33 ms */
#define VCP2_DFLT_PULSE_BREAK_MAX           (100 * 8)
#define VCP2_DFLT_PULSE_MAKE_MIN            (17 * 8)
#define VCP2_DFLT_PULSE_MAKE_MAX            (75 * 8)
#define VCP2_DFLT_PULSE_INTER_DIG_MIN       (250 * 8)
#define VCP2_DFLT_PULSE_FLASH_MIN           (250 * 8)
#define VCP2_DFLT_PULSE_FLASH_MAX           (1300 * 8)

/* VP_DEVICE_OPTION_ID_PULSE2 */
#define VCP2_DFLT_PULSE2_BREAK_MIN          (0 * 8)
#define VCP2_DFLT_PULSE2_BREAK_MAX          (0 * 8)
#define VCP2_DFLT_PULSE2_MAKE_MIN           (0 * 8)
#define VCP2_DFLT_PULSE2_MAKE_MAX           (0 * 8)
#define VCP2_DFLT_PULSE2_INTER_DIG_MIN      (0 * 8)
#define VCP2_DFLT_PULSE2_FLASH_MIN          (0 * 8)
#define VCP2_DFLT_PULSE2_FLASH_MAX          (0 * 8)

/* VP_DEVICE_OPTION_ID_CRITICAL_FLT */
#define VCP2_DFLT_CRITICAL_FLT_AC_DIS_EN    1
#define VCP2_DFLT_CRITICAL_FLT_DC_DIS_EN    1
#define VCP2_DFLT_CRITICAL_FLT_THERM_DIS_EN 1

/* VP_DEVICE_OPTION_ZERO_CROSS */
#define VCP2_DFLT_ZERO_CROSS                VP_OPTION_ZC_M4B

/* VP_OPTION_ID_RAMP2STBY */
#define VCP2_DFLT_RAMP2STBY                 0

/* VP_OPTION_ID_PULSE_MODE */
#define VCP2_DFLT_PULSE_MODE                VP_OPTION_PULSE_DECODE_OFF

/* VP_OPTION_ID_CODEC */
#define VCP2_DFLT_CODEC                     VP_OPTION_ALAW

/* VP_OPTION_ID_PCM_HWY */
#define VCP2_DFLT_PCM_HWY                   VP_OPTION_HWY_A

/* VP_OPTION_ID_LOOPBACK */
#define VCP2_DFLT_LOOPBACK                  VP_OPTION_LB_OFF

/* VP_OPTION_ID_LINE_STATE */
#define VCP2_DFLT_LINE_STATE_BATTREV        0
#define VCP2_DFLT_LINE_STATE_BAT            VP_OPTION_BAT_AUTO

/* VP_OPTION_ID_EVENT_MASK */
#define VCP2_DFLT_EVENT_MASK_FAULT          0
#define VCP2_DFLT_EVENT_MASK_SIGNALING      0
#define VCP2_DFLT_EVENT_MASK_RESPONSE       0
#define VCP2_DFLT_EVENT_MASK_TEST           0
#define VCP2_DFLT_EVENT_MASK_PROCESS        0
#define VCP2_DFLT_EVENT_MASK_FXO            0xFFFF
#define VCP2_DFLT_EVENT_MASK_PACKET         0xFFFF

/* VP_OPTION_ID_RING_CNTRL */
#define VCP2_DFLT_RING_CNTRL_ZEROCROSS      VCP2_DFLT_ZERO_CROSS
#define VCP2_DFLT_RING_CNTRL_RINGEXIT_DBNC  (100 * 8) /* 100ms */
#define VCP2_DFLT_RING_CNTRL_RINGEXIT_STATE VP_LINE_TALK

/* VP_OPTION_ID_DTMF_MODE */
#define VCP2_DFLT_DTMF_MODE_CONTROL         VP_OPTION_DTMF_DECODE_OFF
#define VCP2_DFLT_DTMF_MODE_DIRECTION       VP_DIRECTION_US

/* VP_OPTION_ID_PCM_TXRX_CNTRL */
#define VCP2_DFLT_PCM_TXRX_CNTRL            VP_OPTION_PCM_BOTH

#endif /* _VCP2_HBI_H */
