/*
 * vcp2_ptable.h
 *
 * This file specifies the layout of the VCP2's profile table.  This table
 * allows the application, using VpInitProfile(), to pre-load profiles into
 * the VCP2 device for later use by other API functions.  The layout of the
 * table can be changed in this file, with no firmware changes necessary.
 * Please contact Zarlink for help in modifying this file.  Change it at your
 * own risk!
 *
 * Copyright (c) 2008, Zarlink Semiconductor, Inc.
 */

/*
 * There are 16 HBI pages.  Each page is 128 words (256 bytes) in length.  The
 * following locations cannot be used for profile storage:
 *  - Page 3 contains the command mailbox.
 *  - The first 100 words of page 4 contain the response mailbox.
 *  - Page 15 contains state registers.
 * All other pages can be used for profile storage, according to the layout
 * specified below.  Offsets and lengths are specified in words.
 */

/* Device profiles */
#define VCP2_DEV_PROFILE_PAG(n)     4
#define VCP2_DEV_PROFILE_OFF(n)     (0x6C)
#define VCP2_DEV_PROFILE_LEN        20
#define VCP2_DEV_PROFILE_COUNT      1

/* DC profiles */
#define VCP2_DC_PROFILE_PAG(n)      0
#define VCP2_DC_PROFILE_OFF(n)      (22 * (n))
#define VCP2_DC_PROFILE_LEN         22
#define VCP2_DC_PROFILE_COUNT       3

/* AC profiles */
#define VCP2_AC_PROFILE_PAG(n)      n
#define VCP2_AC_PROFILE_OFF(n)      (0x51)
#define VCP2_AC_PROFILE_LEN         47
#define VCP2_AC_PROFILE_COUNT       3

/* Caller ID profiles */
#define VCP2_CID_PROFILE_PAG(n)     (5 + ((n) / 2))
#define VCP2_CID_PROFILE_OFF(n)     (64 * ((n) % 2))
#define VCP2_CID_PROFILE_LEN        64
#define VCP2_CID_PROFILE_COUNT      10

/* Metering profiles */
#define VCP2_MTR_PROFILE_PAG(n)     (0xC + (n))
#define VCP2_MTR_PROFILE_OFF(n)     (0x6C)
#define VCP2_MTR_PROFILE_LEN        11
#define VCP2_MTR_PROFILE_COUNT      2

/* Tone profiles */
#define VCP2_TONE_PROFILE_PAG(n)    (1 + ((n) / 5))
#define VCP2_TONE_PROFILE_OFF(n)    (16 * ((n) % 5))
#define VCP2_TONE_PROFILE_LEN       16
#define VCP2_TONE_PROFILE_COUNT     10

/* Ring cadence profiles */
#define VCP2_RINGCAD_PROFILE_PAG(n) (0xD + (((n) + 2) / 3))
#define VCP2_RINGCAD_PROFILE_OFF(n) (36 * (((n) + 2) % 3))
#define VCP2_RINGCAD_PROFILE_LEN    36
#define VCP2_RINGCAD_PROFILE_COUNT  4

/* Tone cadence profiles */
#define VCP2_TONECAD_PROFILE_PAG(n) (0xA + ((n) / 3))
#define VCP2_TONECAD_PROFILE_OFF(n) (19 * ((n) % 3))
#define VCP2_TONECAD_PROFILE_LEN    36
#define VCP2_TONECAD_PROFILE_COUNT  11

/* Ring profiles */
#define VCP2_RING_PROFILE_PAG(n)    (0xA + (n))
#define VCP2_RING_PROFILE_OFF(n)    0x72
#define VCP2_RING_PROFILE_LEN       16
#define VCP2_RING_PROFILE_COUNT     2
