#include <stdio.h>
#include <unistd.h>
#include "vp_api.h"
#include "hbi_common.h"

#define term_printf printf

#define MPI_LOG_START       0x0000
#define MPI_LOG_SIZE        0x1000
#define MPI_LOG_PTR_ADDR    0xC000

uint16 mpiLogPtr;

int showMpi(VpDeviceIdType deviceId) {
    uint16 mpiLogEnd, mpiWord;
    uint32 ambaAddr;

    VpHbiAmbaRdWr(FALSE, deviceId, (uint32) MPI_LOG_PTR_ADDR, 0, &mpiLogEnd);
    if (mpiLogPtr == mpiLogEnd) return 0;

    /* Display the rest of the data. */
    if ((mpiLogPtr % 15) != 0) {
        term_printf("MPI:");
    }

    while (mpiLogPtr != mpiLogEnd) {
        if ((mpiLogPtr % 15) == 0) {
            term_printf("MPI:");
        }
        /* Copy word from MPI log to local buffer. */
        ambaAddr = MPI_LOG_START + (uint32)mpiLogPtr;
        VpHbiAmbaRdWr(FALSE, deviceId, ambaAddr, 0, &mpiWord);
        term_printf("%4.4X ", mpiWord);
        if ((mpiLogPtr % 15) == 14) {
            term_printf("\n");
        }
        mpiLogPtr++;
        mpiLogPtr %= MPI_LOG_SIZE;
    }
    if ((mpiLogPtr % 15) != 0) {
        term_printf("\n");
    }

    /* Display new mpiLogEnd value. */
    /* term_printf("TXT: mpiLogEnd = %4.4X + %4.4X\n", MPI_LOG_START,
            mpiLogEnd); */

    return 1;
}

int main(int argc, char *argv[]) {
    int deviceId = 0;

    if (
        (argc != 2) ||
        (sscanf(argv[1], "%X", &deviceId) != 1)
    ) {
        printf("Usage: %s device_id\n", argv[0]);
        return 1;
    }


    VpHbiAmbaRdWr(FALSE, deviceId, (uint32) MPI_LOG_PTR_ADDR, 0, &mpiLogPtr);

    while(1) {
        if (!showMpi(deviceId)) {
            /* If idle, wait 100 ms before trying again. */
            usleep(10000);
        }
    }
}


