/*
 * app_des.h
 *
 * This file contains declarations that are specific to an application.
 *
 * Copyright (c) 2008, Zarlink Semiconductor, Inc.
 */

#ifndef APP_DES_H
#define APP_DES_H

#include "vp_api.h"
/* The following defintion is needed to be able to compile different
 * versions of VCP support required for 880 and 790 series SLACs. This
 * would eventually be removed (once the firmware supports necessary
 * profile changes); This definition is used in the application and
 * the API and hence this defintion is present in the HAL */
#define VP_CC_VCP_790_SERIES  /* For VCP controlling 790 Series */
#undef VP_CC_VCP_880_SERIES  /* For VCP controlling 880 Series */

#if defined(VP_CC_VCP_790_SERIES) && defined(VP_CC_VCP_880_SERIES)
#error Please define only ONE conditional compile option (either \
            VP_CC_VCP_790_SERIES or VP_CC_VCP_880_SERIES)
#endif
#if (!defined(VP_CC_VCP_790_SERIES)) && (!defined(VP_CC_VCP_880_SERIES))
#error Please define AT LEAST one conditional compile option (either \
            VP_CC_VCP_790_SERIES or VP_CC_VCP_880_SERIES)
#endif

/* Specify the Chip Select ID to be used */
#define USE_CHIP_SELECT_ID          (0)

/******************************************************************************
 *                           COMPILE-TIME OPTIONS                             *
 ******************************************************************************/
/* Define VCP Hardware resorces on the Board; Scale these numbers as per your
 * system architecture */
#define MAX_DEVICES_ON_BOARD    1

#if defined(VP_CC_VCP_790_SERIES) && defined(VP_CC_VCP_880_SERIES)
#error Please define only ONE conditional compile option (either \
            VP_CC_VCP_790_SERIES or VP_CC_VCP_880_SERIES)
#endif
#if (!defined(VP_CC_VCP_790_SERIES)) && (!defined(VP_CC_VCP_880_SERIES))
#error Please define AT LEAST one conditional compile option (either \
            VP_CC_VCP_790_SERIES or VP_CC_VCP_880_SERIES)
#endif

#if defined(VP_CC_VCP_790_SERIES)
/* 790 SLAC supports 4 lines */
#define MAX_LINES_ON_BOARD      4
#else
/* 880 SLAC supports 2 lines */
#define MAX_LINES_ON_BOARD      2
#endif /* VP_CC_VCP_790_SERIES */

EXTERN VpStatusType MpiTestAppMain(void);
EXTERN VpStatusType VtdEventHandler(VpEventType *pEvent);

#endif /* APP_DES_H */



