/** \file main.c
 * main.c
 *
 * This file contains the main function for the vcp mpi test.
 */

#include <stdio.h>

#include "vp_api.h"     /* VoicePATH API II functions and types */
#include "app_des.h"    /* Provides Description of hardware and VCP-firmware
                         * product type*/
#include "vp_hal.h"

#ifdef _CXA
#include "board.h"      /* for controlling the VCP Dev Board (serial port,
                         * CPLD) */
#else
#include "vp_hal.h"     /* For debug print statement redirection */
#include "brd_init.h"
#endif /* _CXA */

#if defined(VP_CC_VCP_790_SERIES) && defined(VP_CC_VCP_880_SERIES)
#error Please define only ONE conditional compile option (either \
            VP_CC_VCP_790_SERIES or VP_CC_VCP_880_SERIES)
#endif
#if (!defined(VP_CC_VCP_790_SERIES)) && (!defined(VP_CC_VCP_880_SERIES))
#error Please define AT LEAST one conditional compile option (either \
            VP_CC_VCP_790_SERIES or VP_CC_VCP_880_SERIES)
#endif

int main(void);

#ifdef _CXA
_rom    /* store boot image in flash memory */
#endif /* _CXA */
#ifdef  VP_CC_VCP_790_SERIES
#include "boot_image_790_mpi.h"
#else
#include "boot_image_880_mpi.h"
#endif /* VP_CC_VCP_790_SERIES */
#ifdef _CXA
_huge uint8 bootImageBuf[sizeof(mpiTestBootImage)]; /* buffer for copying the boot
                                                  * image into RAM */
#else
uint8 bootImageBuf[sizeof(mpiTestBootImage)]; /* buffer for copying the boot
                                                  * image into RAM */
#endif /* _CXA */
VpImagePtrType bootImage = bootImageBuf;


int main(void) {
    VpStatusType retval;
    char *retstring[] = {
        "VP_STATUS_SUCCESS",
        "VP_STATUS_FAILURE",
        "VP_STATUS_FUNC_NOT_SUPPORTED",
        "VP_STATUS_INVALID_ARG",
        "VP_STATUS_MAILBOX_BUSY",
        "VP_STATUS_ERR_VTD_CODE",
        "VP_STATUS_OPTION_NOT_SUPPORTED",
        "VP_STATUS_ERROR_VERIFY",
        "VP_STATUS_ERROR_DEVICE_BUSY",
        "VP_STATUS_ERROR_MAILBOX_EMPTY",
        "VP_STATUS_ERROR_MAILBOX_DATA",
        "VP_STATUS_ERROR_HBI",
        "VP_STATUS_ERROR_IMAGE",
        "VP_STATUS_ERROR_IN_CRTCL_SECTN",
        "VP_STATUS_ERR_PROFILE"};
    uint32 b;

#ifdef _CXA
    /* Initialize the host processor. */
    host_init();

    /* Clear the screen. */
    term_putc('\12');
#else
    InitializeBoard();
#endif /* _CXA */

    /* Copy the VCP firmware image from flash into RAM. */
    for (b = 0; b < mpiTestBootImageLen; b++) {
        bootImage[b] = mpiTestBootImage[b];
    }

    /* Run the MPI Test application. */
    retval = MpiTestAppMain();

    term_printf("returned %s.\n\n", retstring[retval]);

    while (1);
    return 0;
}

