/*
 * framer_dummy.h
 *
 * This file contains a dummy implementation of DS2155 Framer implementation.
 * Since this is dummy implemenation, these functin does nothing (other than
 * printing a debug statement. This functions in this file need to be replaced
 * with appropriate implementation.
 *
 * Copyright (c) 2008, Zarlink Semiconductor, Inc.
 */

#ifndef FRAMER_DUMMY_H
#define FRAMER_DUMMY_H

#include "vp_api_types.h"

#define FLIU_REMOTE     0x00
#define FLIU_LOCAL      0x01

/* The connection signal wink time and delay */
#define FLIU_POLLTIME   25 /* Time in mS */
#define FLIU_WINKTIME   50 /* Time in mS */
#define FLIU_MSGDELAY   8  /* Time in polling periods */

/************************ ENUMS ******************************/
typedef enum
{
    LINE_AVAILABLE = 0,	    /* The line is available for connection */
    LINE_BUSY,              /* The line is not available */
   	LINE_UNAVAILABLE,       /* The line can not be accessed now*/
    LINE_OOS,           	/* The line is out of service */
    LINE_SIGNAL_ENUM_SIZE = FORCE_STANDARD_C_ENUM_SIZE /* Portability Req. */
} FliuSignals;

typedef enum
{
    NO_FRAMER = 0,			/* No framer was detected */
    T1_FRAMER,				/* A ds2152 was detected */
    E1_FRAMER,				/* A ds2154 was detected */
    T1_E1_FRAMER,
    FRAMER_TYPE_ENUM_SIZE = FORCE_STANDARD_C_ENUM_SIZE /* Portability Req. */
} FliuType;

typedef enum
{
    T1D4_MODE = 0,			/* T1-D4 mode, 24 channels, rbs=(A/B) */
    T1ESF_MODE,				/* T1-ESF mode, 24 channels, rbs=(A/B/C/D)*/
    E1PCM31_MODE,			/* E1 PCM31 mode, 31 voice channels, W/O CAS */
    E1PCM30_MODE,           /* E1 PCM30 mode, 30 voice channels, W CAS */
    FLIU_MODE_ENUM_SIZE = FORCE_STANDARD_C_ENUM_SIZE /* Portability Req. */
} FliuMode;

typedef enum
{
    TIMING_SOLO = 0,		/* Only one VP-Demo Board board is present,
                             * no remote */
    TIMING_MASTER,			/* This VP-Demo Board is the timing master. */
    TIMING_SLAVE,		    /* This VP-Demo Board is the timing master.  */
    FLIU_TIM_ENUM_SIZE = FORCE_STANDARD_C_ENUM_SIZE /* Portability Req. */
} FliuTiming;

typedef enum
{
    NO_MSG = 0,				/* No message was received */
    FLASH_MSG = 1,          /* The flash message */
    DISCONNECT_MSG = 2,	    /* The disconnect message was received */
    CONNECT_MSG,			/* The connect message was received */
    FLIU_REMOTEM_ENUM_SIZE = FORCE_STANDARD_C_ENUM_SIZE /* Portability Req. */
} FliuRemoteMsg;

typedef enum
{
	FLIU_NO_REMOTE = 0,
	FLIU_VPDB_REMOTE = 1,
	FLIU_UNKNOWN_REMOTE = 2,
    FLIU_REMOTE_ENUM_SIZE = FORCE_STANDARD_C_ENUM_SIZE /* Portability Req. */
} FliuRemote;


/* Structs */
/* Incomming call information structure definition */
struct ConnectSigStruct
{
    uint8 timeSlot;     /* The time slot to send the signaling on */
    uint8 line; 		/* The line number fo the connection */
    uint8 toggle;		/* The number of times to toggle the sig */
};

EXTERN FliuTiming timingMode;
EXTERN FliuRemote fliuRemote;
EXTERN FliuMode fliuMode;

/********************** Function ProtoTypes *******************/
FliuType FliuInit(void);
void FliuSetFraming(FliuMode mode);
void FliuSetSignal(uint8 line, FliuSignals signal);
FliuRemoteMsg FliuIncommingMsg(uint8 * rLine,uint8 * lLine);
FliuSignals FliuGetSignal(uint8 line, uint8 lFlag);
void FliuConnectRemote(uint8 remoteLine,uint8 localLine);
void FliuDisconnectRemote(uint8 remoteLine,uint8 localLine);
void FliuFlashRemote(uint8 remoteLine, uint8 localLine);
void SetLoopBack(uint8 timeSlot);
void ClearLoopBack(uint8 timeSlot);
void FliuModeDetect(void);
void FliuSetTxIdle(uint8 timeSlot);
void FliuSetTxActive(uint8 timeSlot);
bool FliuTestPort(void);
void PutSignal(uint8 timeSlot, uint8 sigMask);
uint8 GetSignal(uint8 timeSlot);


#endif /* FRAMER_DUMMY_H */


