/*
 * profiles8_880.h --
 *
 * This header file exports the Profile data types
 *
 * Copyright (c) 2008 Zarlink Semiconductor Inc.
 *
 * Project Info --
 *   File:  C:\Zarlink Semiconductor\VoicePath_SDK_II\demo_apps\mini_pbx\vp880_vpwiz_prj\LE71HE0803-MiniPBX.vpw
 *   Type:  VP880-CP5621 VoicePort MiniPBX Project (Line Module LE71HE0803)
 *   Date:  Thursday, August 19, 2004 20:05:04
 */

#ifndef PROFILES8_880_H
#define PROFILES8_880_H

#include "vp_api_types.h"
#include "app_des.h"    /* Provides Description of hardware and VCP-firmware
                         * product type*/
#ifndef VP_CC_VCP_790_SERIES


/************** Device Parameters **************/
/* Device Profile */
extern const VpProfileDataType DEV_PROFILE[];

/************** AC Filter Coefficients **************/
extern const VpProfileDataType AC_600R_FXO[];        /* AC 600 FXO Coefficients */
extern const VpProfileDataType AC_600R_FXS[];        /* AC 600 FXS Coefficients */

/************** DC Feed Parameters **************/
extern const VpProfileDataType DC_25MA_CC[];         /* 25 mA current feed */
extern const VpProfileDataType DC_40MA_RF[];         /* 40mA Resistive feed */

/************** Ring Signal Parameters **************/
extern const VpProfileDataType RING_20HZ_SINE[];     /* 20Hz, Sinewave ringing, 66Vpk */
extern const VpProfileDataType RING_25HZ_SINE[];     /* 25Hz, Sinewave ringing, 80Vpk */
extern const VpProfileDataType RING_40HZ_TRAP[];     /* 40Hz trapezoidal ringing, Vpk = 80V, CF = 1.25 */

/************** Call Progress Tones **************/
extern const VpProfileDataType TONE_DIAL[];          /* US Dial Tone */
extern const VpProfileDataType TONE_SIT[];           /* Special Information Tone (Called Number Not Connected) */
extern const VpProfileDataType TONE_BUSY[];          /* Busy Signal */
extern const VpProfileDataType TONE_RINGBACK[];      /* Standard Ringback */
extern const VpProfileDataType TONE_CALLWAIT[];      /* Call Waiting Beep */
extern const VpProfileDataType TONE_REORDER[];       /* US Reorder tone */
extern const VpProfileDataType TONE_ONEKHZ_L[];      /* A 1kHz tone at -10dBm0 */
extern const VpProfileDataType TONE_ONEKHZ_H[];      /* A 1kHz tone at 0dBm0 */
extern const VpProfileDataType TONE_CLI[];           /* Caller ID Alert Tone for UK Cadence */
extern const VpProfileDataType TONE_ROH[];           /* Receiver Off-Hook */

/************** Cadence Definitions **************/
extern const VpProfileDataType TONE_CAD_DIAL0[];     /* Standard dial tone cadence */
extern const VpProfileDataType TONE_CAD_DIAL1[];     /* Stutter dial tone cadence */
extern const VpProfileDataType TONE_CAD_BUSY0[];     /* Busy signal cadence (0.5 sec on 0.5 sec off) */
extern const VpProfileDataType TONE_CAD_REORDER[];   /* Tone Reorder cadence (0.25 sec on 0.25 sec off) */
extern const VpProfileDataType RING_CAD_STD[];       /* Standard Ringing Cadence (2 sec on 4 sec off) */
extern const VpProfileDataType TONE_CAD_RNGBACK[];    /* Ringback Cadence */
extern const VpProfileDataType RING_CAD_ON[];        /* Ringing Always On */
extern const VpProfileDataType TONE_CAD_ROH[];       /* Receiver Off-Hook */
extern const VpProfileDataType TONE_CAD_SIT[];       /* SIT Cadence */
extern const VpProfileDataType RING_CAD_UK_CID[];    /* Ringing cadence with UK CID */
extern const VpProfileDataType RING_CAD_US_CID[];    /* Ringing cadence with US CID */
extern const VpProfileDataType RING_CAD_NOCID[];     /* Ringing cadence no CID*/


/************** Caller ID **************/
extern const VpProfileDataType CLI_TYPE1_US[];       /* US Caller ID (Type 1 - On-Hook) */
extern const VpProfileDataType CLI_TYPE1_UK[];       /* UK Caller ID (Type 1 - On-hook) */
extern const VpProfileDataType CLI_TYPE2_US[];       /* US and UK Type 2 Caller ID */

/************** Metering Profile **************/
extern const VpProfileDataType METER_PROFILE[];      /* Metering */

/************** FXO/Dialing Profile **************/
extern const VpProfileDataType FXO_DIALING[];        /* FXO/Dialing Profile */

#endif /* VP_CC_VCP_790_SERIES */
#endif /* PROFILES8_880_H */



