/*
 * app_des.h
 *
 * This file contains declarations that are specific to an application.
 *
 * Copyright (c) 2008, Zarlink Semiconductor, Inc.
 */

#ifndef APP_DES_H
#define APP_DES_H

#include "vp_api.h"

#define VP_CC_VCP2_SERIES  /* For VCP2 */

/* Specify the Chip Select ID to be used */
#define USE_CHIP_SELECT_ID          (0)

/******************************************************************************
 *                           COMPILE-TIME OPTIONS                             *
 ******************************************************************************/
/* Select the application you want to build; Note that applcations are mutually
 * exclusive. Only one type of application can be built (define only one). */
#undef USING_T1_ESF_LS_APP
#define USING_QUICK_START_APP

#undef USE_2MHZ_PCLK /* Define this to use 2 MHZ PCLK; If this is not
                       * defined it uses 8Mhz PCLK */

#if defined(USING_QUICK_START_APP) && defined(USING_T1_ESF_LS_APP)
#undef USING_T1_ESF_LS_APP  /* Select the default quick start application */
#endif

/* Define VCP2 Hardware resorces on the Board; Scale these numbers as per your
 * system architecture */
#define MAX_DEVICES_ON_BOARD    1

/* 790 SLAC supports 4 lines */
#define MAX_LINES_ON_BOARD      4
/* Define the following if your hardware has LCAS (else undefine) */
#define LCAS_PRESENT_IN_THE_SYSTEM
#define LINES_FROM_WHICH_LCAS_IS_PRESENT   0

#define MAX_DTMF_DETECTION_LINES    4   /* Number of lines for which DTMF
                                         * detection is enabled */

#ifdef USING_T1_ESF_LS_APP
/*******************************************************************************
 *                   T1-ESF Loop Start Application function prototypes         *
 ******************************************************************************/
EXTERN VpStatusType T1EsfLsMain(void);
EXTERN VpStatusType T1EsfLsEventHandler(VpEventType *pEvent);
EXTERN VpStatusType FramerEventHandler(uint8 chanId, uint8 abcdEvent);
#endif /* USING_T1_ESF_LS_APP */

#ifdef USING_QUICK_START_APP
/*******************************************************************************
 *                       Quick start application function prototypes           *
 ******************************************************************************/
EXTERN VpStatusType QuickStartAppMain(void);
EXTERN VpStatusType VtdEventHandler(VpEventType *pEvent);
#endif /* USING_QUICK_START_APP */



#endif /* APP_DES_H */




