/** \file main.c
 * main.c
 *
 * This file contains the main function for the vcp2 quickstart application.
 */

#include <stdio.h>

#include "vp_api.h"     /* VoicePATH API II functions and types */
#include "app_des.h"    /* Provides Description of hardware and VCP2-firmware
                         * product type*/
#include "vp_hal.h"

#ifdef _CXA
#include "board.h"      /* for controlling the VCP2 Dev Board (serial port,
                         * CPLD) */
#else
#include "vp_hal.h"     /* For debug print statement redirection */
#include "brd_init.h"
#endif /* _CXA */

int main(void);

#ifdef _CXA
_rom    /* store boot image in flash memory */
#endif /* _CXA */

#include "boot_image_790.h"

#ifdef _CXA
_huge uint8 bootImageBuf[sizeof(dspBootStream)]; /* buffer for copying the boot
                                                  * image into RAM */
#else
uint8 bootImageBuf[sizeof(dspBootStream)]; /* buffer for copying the boot
                                                  * image into RAM */
#endif /* _CXA */
VpImagePtrType bootImage = bootImageBuf;


int main(void) {
    VpStatusType retval;
    char *retstring[] = {
        "VP_STATUS_SUCCESS",
        "VP_STATUS_FAILURE",
        "VP_STATUS_FUNC_NOT_SUPPORTED",
        "VP_STATUS_INVALID_ARG",
        "VP_STATUS_MAILBOX_BUSY",
        "VP_STATUS_ERR_VTD_CODE",
        "VP_STATUS_OPTION_NOT_SUPPORTED",
        "VP_STATUS_ERROR_VERIFY",
        "VP_STATUS_ERROR_DEVICE_BUSY",
        "VP_STATUS_ERROR_MAILBOX_EMPTY",
        "VP_STATUS_ERROR_MAILBOX_DATA",
        "VP_STATUS_ERROR_HBI",
        "VP_STATUS_ERROR_IMAGE",
        "VP_STATUS_ERROR_IN_CRTCL_SECTN",
        "VP_STATUS_ERR_PROFILE"};
    uint32 b;

#ifdef _CXA
    /* Initialize the host processor. */
    host_init();

    /* Clear the screen. */
    term_putc('\12');
#else
    InitializeBoard();
#endif /* _CXA */

    /* Copy the VCP2 firmware image from flash into RAM. */
    for (b = 0; b < dspBootStreamLen; b++) {
        bootImage[b] = dspBootStream[b];
    }

    /* Run the QuickStart application. */
    retval = QuickStartAppMain();

    term_printf("returned %s.\n\n", retstring[retval]);

    while (1);
    return 0;
}



