/*
 * profiles8_790.c --
 *
 * This file contains profile data in byte format
 *
 * Copyright (c) 2008 Zarlink Inc.
 *
 * Project Info --
 *   File:  C:\Zarlink\VoicePath_SDK_II\demo_apps\mini_pbx\vp880_vpwiz_prj\LE71HE0803-MiniPBX.vpw
 *   Type:  VP880-CP5621 VoicePort MiniPBX Project (Line Module LE71HE0803)
 *   Date:  Thursday, August 19, 2004 20:05:04
 */

#include "profiles8_790.h"
#include "app_des.h"    /* Provides Description of hardware and VCP2-firmware
                         * product type*/
#ifdef VP_CC_VCP2_SERIES

/************** Device Parameters **************/
const VpProfileDataType DEV_PROFILE[] =
{
    /* Device Profile */
    /* Header Info */      0x00, 0xFF, 0x00,
    /* System Profile Length */ 0x1A,
    /* Ver, MPI Length       */ 0x00, 0x0C,
    /* Clock Slot */ 0x44, 0x40,
    /* GPI/O Dir  */ 0x38, 0x0F,
    /* GPI/O Data */ 0x3A, 0x00,
    /* RingExitSt */ 0x24, 0x00,
    /* LC Params  */ 0x22, 0x00, 0x55, 0x55,
    /* MPI Length */ 0x02, 0x00,
    /* DCR1       */ 0x46, /*0x37,*/ 0x3f,
    /* MPI Length */ 0x02, 0x00,
    /* CCR        */ 0x30, 0x00,
    /* MPI Length */ 0x02, 0x00,
    /* GlobalMask */ 0x34, 0x8F
};

/************** AC Filter Coefficients **************/

/* AC 600 FXS Coefficients */
const VpProfileDataType AC_600R_FXS[] =
{
  /* AC Profile */
 0xC0, 0x00, 0x00, 0x54, 0x01, 0x52, 0xCA, 0x06, 0x84, 0x80, 0x4E, 0x00,
 0x75, 0xFF, 0x4C, 0xFD, 0xEC, 0xFE, 0x06, 0x02, 0x66, 0x05, 0x1A, 0x8A,
 0x83, 0x2C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 0x40, 0x00, 0x88, 0xFF, 0x71, 0xFD, 0xEE, 0x04, 0x33, 0xFE, 0x22, 0xFD,
 0xCC, 0x41, 0xC8, 0x82, 0x7F, 0xFF, 0x80, 0x3F, 0x64, 0x86, 0x00, 0x52,
 0x00, 0x49, 0x00, 0x53, 0xFF, 0xD7, 0xF8, 0x23, 0xF0, 0x37, 0xF9, 0x87,
 0x96, 0x00, 0x5A, 0x81, 0xAA, 0x00, 0x53, 0x8E, 0x04, 0x8C, 0x04, 0x90,
 0x02, 0x00, 0x00, 0x00
};

/************** DC Feed Parameters **************/

 /* 30mA CC, 10V VAS, 3000 ohm TSH */
const VpProfileDataType DC_30MA_CC[] =
{
  /* DC Profile */
 0x00, 0x01, 0x00, 0x1A, 0x00, 0x18, 0xC6, 0x0F, 0x00, 0x17, 0x00, 0x26,
 0x1E, 0x18, 0x3A, 0x1D, 0x00, 0x0D, 0x1A, 0x33, 0x0A, 0xC2, 0x0D, 0x64,
 0x0D, 0x01, 0x20, 0x00, 0x10, 0x0F
};

/************** Ring Signal Parameters **************/

/* 20Hz, Sinewave ringing, 66Vpk */
const VpProfileDataType RING_20HZ_SINE[] =
{
 /* Sine, 20 Hz, 1.41 CF, 66.00 Vpk, 0.00 Bias */
  /* Ringing Profile */
  /* New Header Info */ 0x00, 0x04, 0x00, 18, 0x00,
  /* Ring Profile MPI Length */ 15,
  /* Sine, 20 Hz, 1.41 CF, 80.00 Vpk, 0.00 Bias */
   0xD2, 0x00, 0x00, 0x01, 0x01, 0x5B, 0x4C, 0x22, 0x22, 0x00, 0x00,
  /* CCR4 - Internal Ringing */
   0x68, 0x00,
  /* I/O Register - No automatic control */
   0x52, 0x60,
  /* Extra Byte for word alignment */ 0x00
};


/************** Call Progress Tones **************/

/* US Dial Tone */
const VpProfileDataType TONE_DIAL[] =
{
    /* Tone Profile */
    /* New Header Info */ 0x00, 0x02, 0x00, 12, 0x00, 0x00, 0x00, 0x00,
    /* 350 Hz, -16.00 dBm0, 440 Hz, -16.00 dBm0 */
    0x11, 0x8A, 0x05, 0x12, 0x16, 0x02, 0x05, 0x12
};

/* A 1kHz tone at -10dBm0 */
const VpProfileDataType TONE_ONEKHZ_L[] =
{
    /* Tone Profile */
    /* New Header Info */ 0x00, 0x02, 0x00, 12, 0x00, 0x00, 0x00, 0x00,
    /* 1000 Hz, -16.00 dBm0, 0 Hz, -16.00 dBm0 */
    0x30, 0xFC, 0x05, 0x12, 0x00, 0x00, 0x00, 0x00
};

/************** Cadence Definitions **************/
/* Standard Ringing Cadence (2 sec on 4 sec off) */
const VpProfileDataType RING_CAD_STD[] =
{
  /* Cadence Profile */
    0x00, 0x08, 0x00, 8, 0x00, 0x02, 0x00,
    3, 0x02, 0xa8, 0x50,
  /* Extra Byte for word alignment */ 0x00
};

/* Tone Cadence Profile for message (A tone message that is played once the user picks up the phone); */
#define BASIC_TIME_UNIT 3
#define DIT     (0x80 + BASIC_TIME_UNIT)
#define DASH    (0x80 + 3 * BASIC_TIME_UNIT)
#define INTRA_LET_SIL   BASIC_TIME_UNIT
#define INTER_LET_SIL   (3 * BASIC_TIME_UNIT)
#define INTER_WORD_SIL  (6 * BASIC_TIME_UNIT)


/* SIT Cadence */
const VpProfileDataType TONE_CAD_SIT[] =
{
    /* Cadence Profile */
    /* New Header Info */
    0x00, 0x03, 0x00, 22, 0x00, 0x00, 0x00,
    /* Tone Cadence Profile for message (A tone message that is played once the user picks up the phone); */
    18, 0x02,
    DASH, INTRA_LET_SIL, DIT, INTRA_LET_SIL, DASH, INTRA_LET_SIL, DIT, INTER_LET_SIL,  /* Morse Letter 'C' */
    DASH, INTRA_LET_SIL, DASH, INTRA_LET_SIL, DIT, INTRA_LET_SIL, DASH, INTER_LET_SIL, /* Morse Letter 'Q' */
    INTER_WORD_SIL
};

const VpProfileDataType RING_CAD_NOCID[] =
{
  /* Cadence Profile */
    0x00, 0x08, 0x00, 8, 0x00, 0x00, 0x00,
    3, 0x02, 0xa8, 0x50,
  /* Extra Byte for word alignment */ 0x00
};

const VpProfileDataType RING_CAD_US_CID[] =
{
  /* Cadence Profile */
    0x00, 0x08, 0x00, 8, 0x00, 0x02, 0x00,
    3, 0x02, 0xa8, 0x50,
  /* Extra Byte for word alignment */ 0x00
};

/************** Caller ID **************/
/* US Caller ID (Type 1 - On-Hook) */
const VpProfileDataType CLI_TYPE1_US[] =
{
  /* Space=2200Hz, Mark=1200Hz, Amp=-7.00dBm */ 
  /* Caller ID Profile */ 
  0x00, 0x05, 0x01, 0x20, 0x00, 0x00, 
  0x09, 0xD4, /* MPI Length and Command */ 
  0x46, 0x66, 0x0E, 0x4B, 0x26, 0x66, 0x00, 0x00, /* MPI Data */
  0x00, 0x01, /* Checksum Computed by device/API */ 
  0x00, 0x10, /* Length of Elements Data */ 
  0x00, 0x06, 0x02, 0x08, /* Silence Interval for 520ms */ 
  0x00, 0x09, 0x00, 0xFA, /* Channel Seizure for 250ms */ 
  0x00, 0x0A, 0x00, 0x96, /* Mark Signal for 150ms */ 
  0x00, 0x0B, /* Message Data */ 
  0x00, 0x0D  /* End of Transmission */ 
};

/************** Metering Profile **************/
const VpProfileDataType METER_PROFILE[] =
{
    /* Profile type MSB (Always 0) */       0,
    /* Profile type LSB */                  7,
    /* Profile Index */                     0,
    /* Meter Profile Length */              8,

    /* Ver, MPI Length      */              0x00, 5,
    /* CCR5 - Smooth, 12kHz */              0x6A, 0x00,
    /* MLIM & MTRA          */              0xD0, 0x3F, 0x20,

    /* Extra Byte for word alignment */     0x00
};


/************** FXO/Dialing Profile **************/


/* end of file profiles8.c */

#endif /* VP_CC_VCP2_SERIES */

